@@ -1,3 +1,9 @@
+"""
+Copyright (c) 2021 by Benjamin Manns
+This file is part of the Semantic Quality Benchmark for Word Embeddings Tool in Python (SeaQuBe).
+:author: Benjamin Manns
+"""
+
 from abc import ABC, abstractmethod
 
 
